/*
 * SCIM-chewing -
 *	Intelligent Chinese Phonetic IM Engine for SCIM.
 *
 * Copyright (c) 2004, 2005
 *	SCIM-chewing Developers. See ChangeLog for details.
 *
 * See the file "COPYING" for information on usage and redistribution
 * of this file.
 */

#ifndef SCIM_CHEWING_CONFIG_ENTRY_H
#define SCIM_CHEWING_CONFIG_ENTRY_H

#define SCIM_CHEWING_SELECTION_KEYS_NUM (9)

#define SCIM_CONFIG_IMENGINE_CHEWING_USER_SELECTION_KEYS \
	"/IMEngine/Chewing/SelectionKeys"

#define SCIM_CONFIG_IMENGINE_CHEWING_USER_KB_TYPE \
	"/IMEngine/Chewing/KeyboardType"

#define SCIM_CONFIG_IMENGINE_CHEWING_ADD_PHRASE_FORWARD \
	"/IMEngine/Chewing/AddPhraseForward"

#define SCIM_CONFIG_IMENGINE_CHEWING_SPACE_AS_SELECTION \
	"/IMEngine/Chewing/SpaceAsSelection"

#define SCIM_CONFIG_IMENGINE_CHEWING_TRIGGER_KEY \
	"/IMEngine/Chewing/TriggerKey"

#define SCIM_CONFIG_IMENGINE_CHEWING_CHI_ENG_KEY \
	"/IMEngine/Chewing/ChiEngKey"

#define SCIM_CONFIG_IMENGINE_CHEWING_USE_CAPSLOCK                "/IMEngine/Chewing/UseCapslock"
#define SCIM_CONFIG_IMENGINE_CHEWING_SHOW_CANDIDATE_COMMENT      "/IMEngine/Chewing/ShowCandidateComment"
//#define SCIM_CONFIG_IMENGINE_CHEWING_TRIGGER_KEY                 "/IMEngine/Chewing/TriggerKey"
//#define SCIM_CONFIG_IMENGINE_CHEWING_CHEWING_HANJA_KEY            "/IMEngine/Chewing/HangulHanjaKey"
//#define SCIM_CONFIG_IMENGINE_CHEWING_MANUAL_MODE_KEY             "/IMEngine/Chewing/ManualModeKey"
#endif

